==> wiliot_core-5.4.3-py3-none-any.whl: wiliot_core/packet_data/config_files/packet_flow_parameters.py <==
#  """
#    Copyright (c) 2016- 2023, Wiliot Ltd. All rights reserved.
#
#    Redistribution and use of the Software in source and binary forms, with or without modification,
#     are permitted provided that the following conditions are met:
#
#       1. Redistributions of source code must retain the above copyright notice,
#       this list of conditions and the following disclaimer.
#
#       2. Redistributions in binary form, except as used in conjunction with
#       Wiliot's Pixel in a product or a Software update for such product, must reproduce
#       the above copyright notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the distribution.
#
#       3. Neither the name nor logo of Wiliot, nor the names of the Software's contributors,
#       may be used to endorse or promote products or services derived from this Software,
#       without specific prior written permission.
#
#       4. This Software, with or without modification, must only be used in conjunction
#       with Wiliot's Pixel or with Wiliot's cloud service.
#
#       5. If any Software is provided in binary form under this license, you must not
#       do any of the following:
#       (a) modify, adapt, translate, or create a derivative work of the Software; or
#       (b) reverse engineer, decompile, disassemble, decrypt, or otherwise attempt to
#       discover the source code or non-literal aspects (such as the underlying structure,
#       sequence, organization, ideas, or algorithms) of the Software.
#
#       6. If you create a derivative work and/or improvement of any Software, you hereby
#       irrevocably grant each of Wiliot and its corporate affiliates a worldwide, non-exclusive,
#       royalty-free, fully paid-up, perpetual, irrevocable, assignable, sublicensable
#       right and license to reproduce, use, make, have made, import, distribute, sell,
#       offer for sale, create derivative works of, modify, translate, publicly perform
#       and display, and otherwise commercially exploit such derivative works and improvements
#       (as applicable) in conjunction with Wiliot's products and services.
#
#       7. You represent and warrant that you are not a resident of (and will not use the
#       Software in) a country that the U.S. government has embargoed for use of the Software,
#       nor are you named on the U.S. Treasury Department’s list of Specially Designated
#       Nationals or any other applicable trade sanctioning regulations of any jurisdiction.
#       You must not transfer, export, re-export, import, re-import or divert the Software
#       in violation of any export or re-export control laws and regulations (such as the
#       United States' ITAR, EAR, and OFAC regulations), as well as any applicable import
#       and use restrictions, all as then in effect
#
#     THIS SOFTWARE IS PROVIDED BY WILIOT "AS IS" AND "AS AVAILABLE", AND ANY EXPRESS
#     OR IMPLIED WARRANTIES OR CONDITIONS, INCLUDING, BUT NOT LIMITED TO, ANY IMPLIED
#     WARRANTIES OR CONDITIONS OF MERCHANTABILITY, SATISFACTORY QUALITY, NONINFRINGEMENT,
#     QUIET POSSESSION, FITNESS FOR A PARTICULAR PURPOSE, AND TITLE, ARE DISCLAIMED.
#     IN NO EVENT SHALL WILIOT, ANY OF ITS CORPORATE AFFILIATES OR LICENSORS, AND/OR
#     ANY CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#     OR CONSEQUENTIAL DAMAGES, FOR THE COST OF PROCURING SUBSTITUTE GOODS OR SERVICES,
#     FOR ANY LOSS OF USE OR DATA OR BUSINESS INTERRUPTION, AND/OR FOR ANY ECONOMIC LOSS
#     (SUCH AS LOST PROFITS, REVENUE, ANTICIPATED SAVINGS). THE FOREGOING SHALL APPLY:
#     (A) HOWEVER CAUSED AND REGARDLESS OF THE THEORY OR BASIS LIABILITY, WHETHER IN
#     CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE);
#     (B) EVEN IF ANYONE IS ADVISED OF THE POSSIBILITY OF ANY DAMAGES, LOSSES, OR COSTS; AND
#     (C) EVEN IF ANY REMEDY FAILS OF ITS ESSENTIAL PURPOSE.
#  """

# here is a list of parameters which are change based on the packet flow version.

packet_flow_parameters = \
    {
        'default': {'sprinkler_num': 6},
        '0x603': {'sprinkler_num': 2},  # all flow version that are equals or bigger then the specified key
    }


def get_flow_param(flow_in, param_name):
    """
    This function extract the value of the specified parameter name based on the packet flow version
    :param flow_in the packet flow version
    :type flow_in str
    :param param_name the flow parameter
    :type param_name str
    """
    default_values = packet_flow_parameters['default']
    if param_name not in default_values.keys():
        raise Exception(f'get_flow_params: param_name is not in the map: {default_values.keys()}')

    value_out = default_values[param_name]
    optional_values = [d for k, d in packet_flow_parameters.items() if k != 'default' and flow_in >= k]
    if optional_values:
        value_out = optional_values[-1][param_name]

    return value_out

==> wiliot_core-5.5.8-py3-none-any.whl: wiliot_core/packet_data/config_files/packet_flow_parameters.py <==
#  """
#    Copyright (c) 2016- 2023, Wiliot Ltd. All rights reserved.
#
#    Redistribution and use of the Software in source and binary forms, with or without modification,
#     are permitted provided that the following conditions are met:
#
#       1. Redistributions of source code must retain the above copyright notice,
#       this list of conditions and the following disclaimer.
#
#       2. Redistributions in binary form, except as used in conjunction with
#       Wiliot's Pixel in a product or a Software update for such product, must reproduce
#       the above copyright notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the distribution.
#
#       3. Neither the name nor logo of Wiliot, nor the names of the Software's contributors,
#       may be used to endorse or promote products or services derived from this Software,
#       without specific prior written permission.
#
#       4. This Software, with or without modification, must only be used in conjunction
#       with Wiliot's Pixel or with Wiliot's cloud service.
#
#       5. If any Software is provided in binary form under this license, you must not
#       do any of the following:
#       (a) modify, adapt, translate, or create a derivative work of the Software; or
#       (b) reverse engineer, decompile, disassemble, decrypt, or otherwise attempt to
#       discover the source code or non-literal aspects (such as the underlying structure,
#       sequence, organization, ideas, or algorithms) of the Software.
#
#       6. If you create a derivative work and/or improvement of any Software, you hereby
#       irrevocably grant each of Wiliot and its corporate affiliates a worldwide, non-exclusive,
#       royalty-free, fully paid-up, perpetual, irrevocable, assignable, sublicensable
#       right and license to reproduce, use, make, have made, import, distribute, sell,
#       offer for sale, create derivative works of, modify, translate, publicly perform
#       and display, and otherwise commercially exploit such derivative works and improvements
#       (as applicable) in conjunction with Wiliot's products and services.
#
#       7. You represent and warrant that you are not a resident of (and will not use the
#       Software in) a country that the U.S. government has embargoed for use of the Software,
#       nor are you named on the U.S. Treasury Department’s list of Specially Designated
#       Nationals or any other applicable trade sanctioning regulations of any jurisdiction.
#       You must not transfer, export, re-export, import, re-import or divert the Software
#       in violation of any export or re-export control laws and regulations (such as the
#       United States' ITAR, EAR, and OFAC regulations), as well as any applicable import
#       and use restrictions, all as then in effect
#
#     THIS SOFTWARE IS PROVIDED BY WILIOT "AS IS" AND "AS AVAILABLE", AND ANY EXPRESS
#     OR IMPLIED WARRANTIES OR CONDITIONS, INCLUDING, BUT NOT LIMITED TO, ANY IMPLIED
#     WARRANTIES OR CONDITIONS OF MERCHANTABILITY, SATISFACTORY QUALITY, NONINFRINGEMENT,
#     QUIET POSSESSION, FITNESS FOR A PARTICULAR PURPOSE, AND TITLE, ARE DISCLAIMED.
#     IN NO EVENT SHALL WILIOT, ANY OF ITS CORPORATE AFFILIATES OR LICENSORS, AND/OR
#     ANY CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#     OR CONSEQUENTIAL DAMAGES, FOR THE COST OF PROCURING SUBSTITUTE GOODS OR SERVICES,
#     FOR ANY LOSS OF USE OR DATA OR BUSINESS INTERRUPTION, AND/OR FOR ANY ECONOMIC LOSS
#     (SUCH AS LOST PROFITS, REVENUE, ANTICIPATED SAVINGS). THE FOREGOING SHALL APPLY:
#     (A) HOWEVER CAUSED AND REGARDLESS OF THE THEORY OR BASIS LIABILITY, WHETHER IN
#     CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE);
#     (B) EVEN IF ANYONE IS ADVISED OF THE POSSIBILITY OF ANY DAMAGES, LOSSES, OR COSTS; AND
#     (C) EVEN IF ANY REMEDY FAILS OF ITS ESSENTIAL PURPOSE.
#  """

# here is a list of parameters which are change based on the packet flow version.
# the flow min and flow mac MUST be ordered

packet_flow_parameters = {
    'sprinkler_num': [
        {'flow_min': None,    'flow_max': '0x602', 'value': 6},
        {'flow_min': '0x603', 'flow_max': None, 'value': 2},
    ],
    'enc_flow': [
        {'flow_min': None, 'flow_max': '0x608', 'value': 'legacy'},
        {'flow_min': '0x609', 'flow_max': '0x609', 'value': 'patch'},
        {'flow_min': '0x60a', 'flow_max': '0x67f', 'value': 'new'},
        {'flow_min': '0x680', 'flow_max': '0x6af', 'value': 'legacy'},
        {'flow_min': '0x6b0', 'flow_max': None, 'value': 'new'},
    ],
    'first_packet_counter': [
        {'flow_min': None, 'flow_max': '0x503', 'value': 251},  # version <= 2.3
        {'flow_min': '0x504', 'flow_max': '0x51f', 'value': 257},  # version 2.4
        {'flow_min': '0x520', 'flow_max': '0x5ff', 'value': 257},  # version 2.5, 2.9
        {'flow_min': '0x600', 'flow_max': None, 'value': 254 + 255*256},  # version 3.0
    ],
    'first_cntr_8_msb': [
        {'flow_min': None, 'flow_max': '0x503', 'value': 0},  # version <= 2.3
        {'flow_min': '0x504', 'flow_max': '0x5ff', 'value': 1},  # version 2.4, 2.5, 2.9
        {'flow_min': '0x600', 'flow_max': None, 'value': 255},  # version 3.0
    ],
    'packets_per_cycle': [
        {'flow_min': None,    'flow_max': '0x602', 'value': 6},
        {'flow_min': '0x603', 'flow_max': None, 'value': 4},
    ]
}


def get_flow_param(flow_in, param_name):
    """
    This function extract the value of the specified parameter name based on the packet flow version
    :param flow_in the packet flow version
    :type flow_in str
    :param param_name the flow parameter
    :type param_name str
    """
    flow_in = flow_in.lower()
    if param_name not in packet_flow_parameters.keys():
        raise Exception(f'get_flow_params: param_name is not in the map: {packet_flow_parameters.keys()}')

    param_values = packet_flow_parameters[param_name]
    for packet_flow in param_values:
        if packet_flow['flow_max'] and flow_in > packet_flow['flow_max']:
            continue
        if packet_flow['flow_min'] and flow_in < packet_flow['flow_min']:
            raise Exception(f'flow_in is {flow_in} but we could not find a match flow')
        return packet_flow['value']
